# Cookies and Local Storage Policy: SAP LeanIX Workspace
### On this page
  * [1. Purpose and scope](https://help.sap.com/docs/leanix/ea/cookies-and-local-storage-policy-sap-leanix-workspace#1.-purpose-and-scope)
  * [2. What is a cookie?](https://help.sap.com/docs/leanix/ea/cookies-and-local-storage-policy-sap-leanix-workspace#2.-what-is-a-cookie?)
  * [3. What is a local storage object?](https://help.sap.com/docs/leanix/ea/cookies-and-local-storage-policy-sap-leanix-workspace#3.-what-is-a-local-storage-object?)
  * [4. Types of cookies and local storage objects used in SAP LeanIX Workspaces](https://help.sap.com/docs/leanix/ea/cookies-and-local-storage-policy-sap-leanix-workspace#4.-types-of-cookies-and-local-storage-objects-used-in-sap-leanix-workspaces)
  * [4.1 List of cookies and local storage objects](https://help.sap.com/docs/leanix/ea/cookies-and-local-storage-policy-sap-leanix-workspace#4.1-list-of-cookies-and-local-storage-objects)
  * [5. How to block or delete cookies and local storage objects](https://help.sap.com/docs/leanix/ea/cookies-and-local-storage-policy-sap-leanix-workspace#5.-how-to-block-or-delete-cookies-and-local-storage-objects)


Cookies and local storage policy for SAP LeanIX workspaces.
